|pypi|


edc-constants
-------------

A collection of constants and choices for the clinicedc/edc projects.



.. |pypi| image:: https://img.shields.io/pypi/v/edc-constants.svg
    :target: https://pypi.python.org/pypi/edc-constants
